--
--  NOISE_GENERATOR.vhd
--
--  Generator a noise tone.
--
--        Copyright (C)2001 - 2002 SEILEBOST
--                   All rights reserved.
--
-- $Id: NOISE_GENERATOR.vhd, v0.1 2002/30/04 00:00:00 SEILEBOST $
--
-- 

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity noise_generator is
    Port ( CLK          : in     std_logic;
           RST          : in     std_logic;
           LD_NOISE     : in     std_logic;
           DATA         : in     std_logic_vector(4 downto 0);
           CLK_N        : out    std_logic );
end noise_generator;

architecture Behavioral of noise_generator is

SIGNAL COUNT   : std_logic_vector(2 downto 0);
SIGNAL ShiftEn : std_logic;
SIGNAL FillSel : std_logic;
SIGNAL DataIn  : std_logic;
SIGNAL lData   : std_logic_vector(4 downto 0);

COMPONENT i_pn_gen port(clk, ShiftEn, FillSel, DataIn_i, RESET : in  std_logic;
                        pn_out_i                               : out std_logic);
END COMPONENT;

begin

U_IPNG :  I_PN_GEN PORT MAP ( CLK      => CLK,
                              ShiftEn  => ShiftEn,
                              FillSel  => FillSel,
                              RESET    => RST,
                              DataIn_i => DataIn,
                              pn_out_i => CLK_N);

 PROCESS(CLK, RST)
 BEGIN
     if (RST = '1') then
        COUNT     <= "101";
        ShiftEn   <= '0';
        FillSel   <= '0';
        DataIn    <= '0';
     elsif rising_edge(CLK) then
        if (LD_NOISE = '1') then
           lData   <= DATA;
           ShiftEn <= '1';
           FillSel <= '1';
        else
          if (COUNT = "000") then
             FillSel <= '0';
          else
              COUNT             <= COUNT - 1;
              DataIn            <= lData(0);
              lData(3 downto 0) <= lData(4 downto 1);
          end if;
        end if;
     end if;
 END PROCESS;
end Behavioral;
